==> mingw-w64-clang-aarch64-flecs-docs-3.2.11-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__cpp__addons__systems.js <==
var group__cpp__addons__systems =
[
    [ "flecs::_", "namespaceflecs_1_1__.html", null ],
    [ "flecs::system_builder< Components >", "structflecs_1_1system__builder.html", null ],
    [ "flecs::system_builder_i< Base, Components >", "structflecs_1_1system__builder__i.html", [
      [ "ctx", "structflecs_1_1system__builder__i.html#a4dea589a99a1e97a4998332c6becfb76", null ],
      [ "interval", "structflecs_1_1system__builder__i.html#ab97725a95f79df7f5ec77a8f3bb45ff5", null ],
      [ "kind", "structflecs_1_1system__builder__i.html#aacc4c809e8c5a4a0c137239a0f9fb100", null ],
      [ "kind", "structflecs_1_1system__builder__i.html#a108cb748eb7350ed94deeefa129ea321", null ],
      [ "multi_threaded", "structflecs_1_1system__builder__i.html#afc1a155d412834f143c3ec7301927f2e", null ],
      [ "no_readonly", "structflecs_1_1system__builder__i.html#a90a589614292efa21e255e16722133db", null ],
      [ "rate", "structflecs_1_1system__builder__i.html#a6a5258e4e5437d8b2f54121d00f7519f", null ],
      [ "rate", "structflecs_1_1system__builder__i.html#a400024e98df7d7aee5d9ebce94877800", null ],
      [ "run", "structflecs_1_1system__builder__i.html#a87ee158021684a9b60b8777d48aa8168", null ],
      [ "tick_source", "structflecs_1_1system__builder__i.html#ad47c0a6fae17be2c0ecd6413209e33ad", null ],
      [ "tick_source", "structflecs_1_1system__builder__i.html#a31d323223a40859844414faece51a845", null ]
    ] ],
    [ "flecs::world::system", "group__cpp__addons__systems.html#ga111f6b0e868528ac6cc4d2259fff1464", null ],
    [ "flecs::world::system", "group__cpp__addons__systems.html#gaae332057aaaa35c3a0821300113dcf5e", null ]
];

==> mingw-w64-clang-aarch64-flecs-docs-4.1.4-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__cpp__addons__systems.js <==
var group__cpp__addons__systems =
[
    [ "flecs::_", "namespaceflecs_1_1__.html", null ],
    [ "flecs::system_builder&lt; Components &gt;", "structflecs_1_1system__builder.html", null ],
    [ "flecs::system_builder_i&lt; Base, Components &gt;", "structflecs_1_1system__builder__i.html", [
      [ "ctx", "structflecs_1_1system__builder__i.html#a4dea589a99a1e97a4998332c6becfb76", null ],
      [ "immediate", "structflecs_1_1system__builder__i.html#a458d428529075c3e9f84eab69145e181", null ],
      [ "interval", "structflecs_1_1system__builder__i.html#ab97725a95f79df7f5ec77a8f3bb45ff5", null ],
      [ "kind", "structflecs_1_1system__builder__i.html#aacc4c809e8c5a4a0c137239a0f9fb100", null ],
      [ "kind", "structflecs_1_1system__builder__i.html#a108cb748eb7350ed94deeefa129ea321", null ],
      [ "multi_threaded", "structflecs_1_1system__builder__i.html#afc1a155d412834f143c3ec7301927f2e", null ],
      [ "rate", "structflecs_1_1system__builder__i.html#a6a5258e4e5437d8b2f54121d00f7519f", null ],
      [ "rate", "structflecs_1_1system__builder__i.html#a400024e98df7d7aee5d9ebce94877800", null ],
      [ "run", "structflecs_1_1system__builder__i.html#a87ee158021684a9b60b8777d48aa8168", null ],
      [ "tick_source", "structflecs_1_1system__builder__i.html#ad47c0a6fae17be2c0ecd6413209e33ad", null ],
      [ "tick_source", "structflecs_1_1system__builder__i.html#a31d323223a40859844414faece51a845", null ]
    ] ],
    [ "flecs::world::system", "group__cpp__addons__systems.html#ga111f6b0e868528ac6cc4d2259fff1464", null ],
    [ "flecs::world::system", "group__cpp__addons__systems.html#ga044c2bfc37acb9f970bb896dea58ad8a", null ]
];
